"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const service_1 = require("../service");
class Run extends command_1.Command {
    run() {
        const { flags } = this.parse(Run);
        service_1.BootstrapUtils.showBanner();
        return new service_1.BootstrapService(this.config.root).run(flags);
    }
}
exports.default = Run;
Run.description = 'It boots the network via docker using the generated `docker-compose.yml` file and configuration. The config and compose methods/commands need to be called before this method. This is just a wrapper for the `docker-compose up` bash call.';
Run.examples = [`$ symbol-bootstrap run`];
Run.flags = {
    help: command_1.flags.help({ char: 'h', description: 'It shows the help of this command.' }),
    target: command_1.flags.string({
        char: 't',
        description: 'the target folder',
        default: service_1.ConfigService.defaultParams.target,
    }),
    detached: command_1.flags.boolean({
        char: 'd',
        description: 'If provided, docker-compose will run with -d (--detached) and this command will wait unit server is running before returning',
    }),
    service: command_1.flags.string({
        char: 's',
        description: 'To start a particular docker compose service by name, example rest-gateway, db, node-peer-0',
    }),
    build: command_1.flags.boolean({
        char: 'b',
        description: 'If provided, docker-compose will run with -b (--build)',
    }),
    timeout: command_1.flags.integer({
        char: 't',
        description: 'If running in detached mode, how long before timing out (in MS)',
        default: service_1.RunService.defaultParams.timeout,
    }),
};
